@@ -1,3 +1,6 @@
+// Licensed under the MIT license, see LICENCE file for details.
+
+//go:build go1.14
 // +build go1.14
 
 package quicktest_test
@@ -37,7 +40,7 @@ func TestCDeferWithoutDone(t *testing.T) {
 func TestCDeferVsCleanupOrder(t *testing.T) {
 	c := qt.New(t)
 	var defers []int
-	testDefer(c, func(c *qt.C) {
+	c.Run("subtest", func(c *qt.C) {
 		c.Defer(func() {
 			defers = append(defers, 0)
 		})
