@@ -149,6 +149,31 @@ Note that the following will fail:
 
 Use the IsNil checker below for this kind of nil check.
 
+ErrorAs
+
+ErrorAs checks that the error is or wraps a specific error type. If so, it
+assigns it to the provided pointer. This is analogous to calling errors.As.
+
+For instance:
+
+    // Checking for a specific error type
+    c.Assert(err, qt.ErrorAs, new(*os.PathError))
+
+    // Checking fields on a specific error type
+    var pathError *os.PathError
+    if c.Check(err, qt.ErrorAs, &pathError) {
+        c.Assert(pathError.Path, Equals, "some_path")
+    }
+
+ErrorIs
+
+ErrorIs checks that the error is or wraps a specific error value. This is
+analogous to calling errors.Is.
+
+For instance:
+
+    c.Assert(err, qt.ErrorIs, os.ErrNotExist)
+
 ErrorMatches
 
 ErrorMatches checks that the provided value is an error whose message matches
@@ -167,6 +192,16 @@ For instance:
     c.Assert([]int{42, 47}, qt.HasLen, 2)
     c.Assert(myMap, qt.HasLen, 42)
 
+Implements
+
+Implements checks that the provided value implements an interface. The
+interface is specified with a pointer to an interface variable.
+
+For instance:
+
+    var rc io.ReadCloser
+    c.Assert(myReader, qt.Implements, &rc)
+
 IsFalse
 
 IsFalse checks that the provided value is false.
@@ -195,6 +230,15 @@ So it's just fine to check an error like this:
 
     c.Assert(err, qt.IsNil)
 
+IsNotNil
+
+IsNotNil is a Checker checking that the provided value is not nil.
+IsNotNil is the equivalent of qt.Not(qt.IsNil)
+
+For instance:
+
+    c.Assert(got, qt.IsNotNil)
+
 IsTrue
 
 IsTrue checks that the provided value is true.
